# Import main components
from .core.silico import Silico
from .core.scales import Scales
from .analysis.peptide import PeptideAnalysis
from .analysis.protein import ProteinAnalysis
from .viz.plots import Plots

# Version info
__version__ = '0.5.0'